# --8<-- [start:imports]
from pydantic import BaseModel


# --8<-- [end:imports]
# --8<-- [start:schemas]
# --8<-- [start:createschema]
class CreateProfileSchema(BaseModel):
    profile_id: int | None = None
    bio: str | None = None


# --8<-- [end:createschema]
# --8<-- [start:readschema]
class ReadProfileSchema(BaseModel):
    id: int
    bio: str | None = None


# --8<-- [end:readschema]
# --8<-- [start:updateschema]
class UpdateProfileSchema(BaseModel):
    bio: str | None = None


# --8<-- [end:updateschema]
# --8<-- [start:deleteschema]
class DeleteProfileSchema(BaseModel):
    pass


# --8<-- [end:deleteschema]
# --8<-- [end:schemas]



# --8<-- [start:imports]
from sqlalchemy import Column, ForeignKey, Integer, String
from sqlalchemy.orm import DeclarativeBase


class Base(DeclarativeBase):
    pass


# --8<-- [end:imports]
# --8<-- [start:model]
class Article(Base):
    __tablename__ = "article"
    id = Column(Integer, primary_key=True)
    author_id = Column(Integer, ForeignKey("author.id"))
    title = Column(String)
    content = Column(String)


# --8<-- [end:model]
